use core::fmt;
use serde::export::Formatter;
use std::error;

/// Simple rust error
///
/// @author Pierre Hubert


/// Simple result type
pub type ResultExecError<E> = Result<E, ExecError>;

#[derive(Debug, Clone)]
pub struct ExecError(pub String);

impl ExecError {
    pub fn new(msg: &str) -> ExecError {
        ExecError(msg.to_string())
    }

    pub fn boxed_new(msg: &str) -> Box<ExecError> {
        Box::new(ExecError(msg.to_string()))
    }

    pub fn boxed_string(msg: String) -> Box<ExecError> {
        Box::new(ExecError(msg))
    }
}

impl fmt::Display for ExecError {
    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
        write!(f, "Encountered error: {}", self.0)
    }
}

impl error::Error for ExecError {}